import { useTranslation } from "next-i18next";

import Container from "components/services/widget/container";
import Block from "components/services/widget/block";
import useWidgetAPI from "utils/proxy/use-widget-api";

export default function Component({ service }) {
  const { t } = useTranslation();
  const { widget } = service;
  const { data, error } = useWidgetAPI(widget, "widget", {
    refreshInterval: 5000,
  });

  if (error) {
    return <Container service={service} error={error} />;
  }

  if (!data) {
    return (
      <Container service={service}>
        <Block label="Cache" />
        <Block label="LRCLib" />
        <Block label="Genius" />
        <Block label="Failed" />
      </Container>
    );
  }

  var failed = data.failed;
  var failed_class = "";
 
  if (data.failed > 0) {
    failed_class = "redfail";
  }




  return (
    <Container service={service}>
      <Block label="Cache" value={t("common.number", { value: data.cache })} />
      <Block label="LRCLib" value={t("common.number", { value: data.lrclib })} />
      <Block label="Genius" value={t("common.number", { value: data.genius })} />
      <Block label="Failed" value={<span class={ failed_class }>{ data.failed }</span>}/>
    </Container>
  );
}

